import {
	INodeProperties,
} from 'n8n-workflow';

export const callOperations = [
	{
		displayName: 'Operation',
		name: 'operation',
		type: 'options',
		displayOptions: {
			show: {
				resource: [
					'call',
				],
			},
		},
		options: [
			{
				name: 'Create',
				value: 'create',
				description: 'Create a call',
			},
			{
				name: 'Delete',
				value: 'delete',
				description: 'Delete a call',
			},
			{
				name: 'Get',
				value: 'get',
				description: 'Retrieve a call',
			},
			{
				name: 'Get All',
				value: 'getAll',
				description: 'Retrieve all calls',
			},
			{
				name: 'Update',
				value: 'update',
				description: 'Update a call',
			},
		],
		default: 'create',
	},
] as INodeProperties[];

export const callFields = [
	// ----------------------------------------
	//               call: create
	// ----------------------------------------
	{
		displayName: 'Contact ID',
		name: 'contactId',
		description: 'ID of the contact to associate the call with',
		type: 'string',
		required: true,
		default: '',
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'create',
				],
			},
		},
	},
	{
		displayName: 'Called At',
		name: 'calledAt',
		description: 'Date when the call happened',
		type: 'dateTime',
		required: true,
		default: '',
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'create',
				],
			},
		},
	},
	{
		displayName: 'Description',
		name: 'content',
		description: 'Description of the call - max 100,000 characters',
		typeOptions: {
			alwaysOpenEditWindow: true,
		},
		type: 'string',
		required: true,
		default: '',
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'create',
				],
			},
		},
	},

	// ----------------------------------------
	//               call: delete
	// ----------------------------------------
	{
		displayName: 'Call ID',
		name: 'callId',
		description: 'ID of the call to delete',
		type: 'string',
		required: true,
		default: '',
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'delete',
				],
			},
		},
	},

	// ----------------------------------------
	//                call: get
	// ----------------------------------------
	{
		displayName: 'Call ID',
		name: 'callId',
		description: 'ID of the call to retrieve',
		type: 'string',
		required: true,
		default: '',
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'get',
				],
			},
		},
	},

	// ----------------------------------------
	//               call: getAll
	// ----------------------------------------
	{
		displayName: 'Return All',
		name: 'returnAll',
		type: 'boolean',
		default: false,
		description: 'Whether to return all results or only up to a given limit',
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'getAll',
				],
			},
		},
	},
	{
		displayName: 'Limit',
		name: 'limit',
		type: 'number',
		default: 50,
		description: 'How many results to return',
		typeOptions: {
			minValue: 1,
		},
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'getAll',
				],
				returnAll: [
					false,
				],
			},
		},
	},

	// ----------------------------------------
	//               call: update
	// ----------------------------------------
	{
		displayName: 'Call ID',
		name: 'callId',
		description: 'ID of the call to update',
		type: 'string',
		required: true,
		default: '',
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'update',
				],
			},
		},
	},
	{
		displayName: 'Update Fields',
		name: 'updateFields',
		type: 'collection',
		placeholder: 'Add Field',
		default: {},
		displayOptions: {
			show: {
				resource: [
					'call',
				],
				operation: [
					'update',
				],
			},
		},
		options: [
			{
				displayName: 'Called At',
				name: 'calledAt',
				description: 'Date when the call happened',
				type: 'dateTime',
				default: '',
			},
			{
				displayName: 'Contact ID',
				name: 'contactId',
				description: 'ID of the contact to associate the call with',
				type: 'string',
				default: '',
			},
			{
				displayName: 'Description',
				name: 'content',
				description: 'Description of the call - max 100,000 characters',
				type: 'string',
				default: '',
			},
		],
	},
] as INodeProperties[];
